| yc_slope | R Documentation |
Compute common slope and curvature measures from a yield curve.
yc_slope(curve)
curve |
A |
A named list with slope measures:
10-year minus 2-year rate (the most common slope measure).
30-year minus 2-year rate.
30-year minus 5-year rate.
10-year minus 3-month rate (term premium proxy).
2 * 5-year minus 2-year minus 10-year (curvature measure).
Returns NA for any measure whose required tenors fall outside the curve range.
maturities <- c(0.25, 0.5, 1, 2, 5, 10, 30)
rates <- c(0.052, 0.050, 0.048, 0.045, 0.042, 0.040, 0.043)
fit <- yc_nelson_siegel(maturities, rates)
yc_slope(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.